Module: Checkend::Integrations::Rails::ControllerMethods
- Defined in:
- lib/checkend/integrations/rails.rb
Overview
Controller methods for Rails integration This module can be included in controllers to add Checkend context tracking
Class Method Summary collapse
Class Method Details
.included(base) ⇒ Object
11 12 13 14 15 16 |
# File 'lib/checkend/integrations/rails.rb', line 11 def self.included(base) base.class_eval do before_action :checkend_set_request_context after_action :checkend_clear_context end end |